from typing import *

import attr

from ..models.input_data_object_type import InputDataObjectType
from ..types import UNSET, Unset

T = TypeVar("T", bound="InputData")


def unset_if_none(_dict: dict, key: Any) -> Union[Any, Unset]:
    if key not in _dict or _dict[key] is None:
        return UNSET
    return _dict[key]


@attr.s(auto_attribs=True)
class InputData:
    """
    Attributes:
        collection_name (str):
        data (List[List[Any]]):
        object_type (Union[Unset, InputDataObjectType]):  Default: InputDataObjectType.INPUTDATA.
    """

    collection_name: str
    data: List[List[Any]]
    object_type: Union[Unset, InputDataObjectType] = InputDataObjectType.INPUTDATA
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def __init__(
        self,
        collection_name: str,
        data: List[List[Any]],
        object_type: Union[Unset, InputDataObjectType] = InputDataObjectType.INPUTDATA,
    ):
        """ """

        self.collection_name = collection_name
        self.data = data
        self.object_type = object_type

    def to_dict(self) -> Dict[str, Any]:
        collection_name = self.collection_name
        data = []
        for data_item_data in self.data:
            data_item = data_item_data

            data.append(data_item)

        object_type: Union[Unset, str] = UNSET
        if not isinstance(self.object_type, Unset):
            object_type = self.object_type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "collection_name": collection_name,
                "data": data,
            }
        )
        if object_type is not UNSET:
            field_dict["object_type"] = object_type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        collection_name = d.pop("collection_name")

        data = []
        _data = d.pop("data")
        for data_item_data in _data:
            data_item = cast(List[Any], data_item_data)

            data.append(data_item)

        _object_type = unset_if_none(d, "object_type")
        object_type: Union[Unset, InputDataObjectType]
        if isinstance(_object_type, Unset):
            object_type = UNSET
        else:
            object_type = InputDataObjectType(_object_type)

        input_data = cls(
            collection_name=collection_name,
            data=data,
            object_type=object_type,
        )

        input_data.additional_properties = d
        return input_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import *

import attr

from ..models.query_meta_params_object_type import QueryMetaParamsObjectType
from ..types import UNSET, Unset

T = TypeVar("T", bound="QueryMetaParams")


def unset_if_none(_dict: dict, key: Any) -> Union[Any, Unset]:
    if key not in _dict or _dict[key] is None:
        return UNSET
    return _dict[key]


@attr.s(auto_attribs=True)
class QueryMetaParams:
    """
    Attributes:
        nprobe (int): Number of units to query. CPU: [1, nlist], GPU: [1, min(2048, nlist)
        object_type (Union[Unset, QueryMetaParamsObjectType]):  Default: QueryMetaParamsObjectType.QUERYMETAPARAMS.
        ef (Union[Unset, int]): Search Scope. Range [top_k, 32768]
        search_k (Union[Unset, int]): The number of nodes to search. -1 means 5% of the whole data. Range {-1} U [top_k,
            n x n_trees]
    """

    nprobe: int
    object_type: Union[Unset, QueryMetaParamsObjectType] = QueryMetaParamsObjectType.QUERYMETAPARAMS
    ef: Union[Unset, int] = UNSET
    search_k: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def __init__(
        self,
        nprobe: int,
        object_type: Union[Unset, QueryMetaParamsObjectType] = QueryMetaParamsObjectType.QUERYMETAPARAMS,
        ef: Union[Unset, int] = UNSET,
        search_k: Union[Unset, int] = UNSET,
    ):
        """ """

        self.nprobe = nprobe
        self.object_type = object_type
        self.ef = ef
        self.search_k = search_k

    def to_dict(self) -> Dict[str, Any]:
        nprobe = self.nprobe
        object_type: Union[Unset, str] = UNSET
        if not isinstance(self.object_type, Unset):
            object_type = self.object_type.value

        ef = self.ef
        search_k = self.search_k

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "nprobe": nprobe,
            }
        )
        if object_type is not UNSET:
            field_dict["object_type"] = object_type
        if ef is not UNSET:
            field_dict["ef"] = ef
        if search_k is not UNSET:
            field_dict["search_k"] = search_k

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        nprobe = d.pop("nprobe")

        _object_type = unset_if_none(d, "object_type")
        object_type: Union[Unset, QueryMetaParamsObjectType]
        if isinstance(_object_type, Unset):
            object_type = UNSET
        else:
            object_type = QueryMetaParamsObjectType(_object_type)

        ef = unset_if_none(d, "ef")

        search_k = unset_if_none(d, "search_k")

        query_meta_params = cls(
            nprobe=nprobe,
            object_type=object_type,
            ef=ef,
            search_k=search_k,
        )

        query_meta_params.additional_properties = d
        return query_meta_params

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import *

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="HitResult")


def unset_if_none(_dict: dict, key: Any) -> Union[Any, Unset]:
    if key not in _dict or _dict[key] is None:
        return UNSET
    return _dict[key]


@attr.s(auto_attribs=True)
class HitResult:
    """ """

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def __init__(
        self,
    ):
        """ """

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        hit_result = cls()

        hit_result.additional_properties = d
        return hit_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import *

import attr

from ..models.index_object_type import IndexObjectType
from ..models.index_params import IndexParams
from ..types import UNSET, Unset

T = TypeVar("T", bound="Index")


def unset_if_none(_dict: dict, key: Any) -> Union[Any, Unset]:
    if key not in _dict or _dict[key] is None:
        return UNSET
    return _dict[key]


@attr.s(auto_attribs=True)
class Index:
    """
    Attributes:
        index_type (str):
        metric_type (str):
        object_type (Union[Unset, IndexObjectType]):  Default: IndexObjectType.INDEX.
        params (Union[Unset, IndexParams]):
    """

    index_type: str
    metric_type: str
    object_type: Union[Unset, IndexObjectType] = IndexObjectType.INDEX
    params: Union[Unset, IndexParams] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def __init__(
        self,
        index_type: str,
        metric_type: str,
        object_type: Union[Unset, IndexObjectType] = IndexObjectType.INDEX,
        params: Union[Unset, IndexParams] = UNSET,
    ):
        """ """

        self.index_type = index_type
        self.metric_type = metric_type
        self.object_type = object_type
        self.params = params

    def to_dict(self) -> Dict[str, Any]:
        index_type = self.index_type
        metric_type = self.metric_type
        object_type: Union[Unset, str] = UNSET
        if not isinstance(self.object_type, Unset):
            object_type = self.object_type.value

        params: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.params, Unset):
            params = self.params.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "index_type": index_type,
                "metric_type": metric_type,
            }
        )
        if object_type is not UNSET:
            field_dict["object_type"] = object_type
        if params is not UNSET:
            field_dict["params"] = params

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        index_type = d.pop("index_type")

        metric_type = d.pop("metric_type")

        _object_type = unset_if_none(d, "object_type")
        object_type: Union[Unset, IndexObjectType]
        if isinstance(_object_type, Unset):
            object_type = UNSET
        else:
            object_type = IndexObjectType(_object_type)

        _params = unset_if_none(d, "params")
        params: Union[Unset, IndexParams]
        if isinstance(_params, Unset):
            params = UNSET
        else:
            params = IndexParams.from_dict(_params)

        index = cls(
            index_type=index_type,
            metric_type=metric_type,
            object_type=object_type,
            params=params,
        )

        index.additional_properties = d
        return index

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import *

import attr

from ..models.query_params import QueryParams
from ..models.vector_query_spec_object_type import VectorQuerySpecObjectType
from ..types import UNSET, Unset

T = TypeVar("T", bound="VectorQuerySpec")


def unset_if_none(_dict: dict, key: Any) -> Union[Any, Unset]:
    if key not in _dict or _dict[key] is None:
        return UNSET
    return _dict[key]


@attr.s(auto_attribs=True)
class VectorQuerySpec:
    """
    Attributes:
        data (List[List[Any]]):
        collection_name (str):
        search_field (str):
        search_params (QueryParams):
        limit (int):
        object_type (Union[Unset, VectorQuerySpecObjectType]):  Default: VectorQuerySpecObjectType.VECTORQUERYSPEC.
        output_fields (Union[Unset, List[str]]):
        expr (Union[Unset, str]):
        partitions (Union[Unset, List[str]]):
        timeout (Union[Unset, float]):
        round_decimal (Union[Unset, int]):  Default: -1.
    """

    data: List[List[Any]]
    collection_name: str
    search_field: str
    search_params: QueryParams
    limit: int
    object_type: Union[Unset, VectorQuerySpecObjectType] = VectorQuerySpecObjectType.VECTORQUERYSPEC
    output_fields: Union[Unset, List[str]] = UNSET
    expr: Union[Unset, str] = UNSET
    partitions: Union[Unset, List[str]] = UNSET
    timeout: Union[Unset, float] = UNSET
    round_decimal: Union[Unset, int] = -1
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def __init__(
        self,
        data: List[List[Any]],
        collection_name: str,
        search_field: str,
        search_params: QueryParams,
        limit: int,
        object_type: Union[Unset, VectorQuerySpecObjectType] = VectorQuerySpecObjectType.VECTORQUERYSPEC,
        output_fields: Union[Unset, List[str]] = UNSET,
        expr: Union[Unset, str] = UNSET,
        partitions: Union[Unset, List[str]] = UNSET,
        timeout: Union[Unset, float] = UNSET,
        round_decimal: Union[Unset, int] = -1,
    ):
        """ """

        self.data = data
        self.collection_name = collection_name
        self.search_field = search_field
        self.search_params = search_params
        self.limit = limit
        self.object_type = object_type
        self.output_fields = output_fields
        self.expr = expr
        self.partitions = partitions
        self.timeout = timeout
        self.round_decimal = round_decimal

    def to_dict(self) -> Dict[str, Any]:
        data = []
        for data_item_data in self.data:
            data_item = data_item_data

            data.append(data_item)

        collection_name = self.collection_name
        search_field = self.search_field
        search_params = self.search_params.to_dict()

        limit = self.limit
        object_type: Union[Unset, str] = UNSET
        if not isinstance(self.object_type, Unset):
            object_type = self.object_type.value

        output_fields: Union[Unset, List[str]] = UNSET
        if not isinstance(self.output_fields, Unset):
            output_fields = self.output_fields

        expr = self.expr
        partitions: Union[Unset, List[str]] = UNSET
        if not isinstance(self.partitions, Unset):
            partitions = self.partitions

        timeout = self.timeout
        round_decimal = self.round_decimal

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "data": data,
                "collection_name": collection_name,
                "search_field": search_field,
                "search_params": search_params,
                "limit": limit,
            }
        )
        if object_type is not UNSET:
            field_dict["object_type"] = object_type
        if output_fields is not UNSET:
            field_dict["output_fields"] = output_fields
        if expr is not UNSET:
            field_dict["expr"] = expr
        if partitions is not UNSET:
            field_dict["partitions"] = partitions
        if timeout is not UNSET:
            field_dict["timeout"] = timeout
        if round_decimal is not UNSET:
            field_dict["round_decimal"] = round_decimal

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        data = []
        _data = d.pop("data")
        for data_item_data in _data:
            data_item = cast(List[Any], data_item_data)

            data.append(data_item)

        collection_name = d.pop("collection_name")

        search_field = d.pop("search_field")

        search_params = QueryParams.from_dict(d.pop("search_params"))

        limit = d.pop("limit")

        _object_type = unset_if_none(d, "object_type")
        object_type: Union[Unset, VectorQuerySpecObjectType]
        if isinstance(_object_type, Unset):
            object_type = UNSET
        else:
            object_type = VectorQuerySpecObjectType(_object_type)

        output_fields = cast(List[str], unset_if_none(d, "output_fields"))

        expr = unset_if_none(d, "expr")

        partitions = cast(List[str], unset_if_none(d, "partitions"))

        timeout = unset_if_none(d, "timeout")

        round_decimal = unset_if_none(d, "round_decimal")

        vector_query_spec = cls(
            data=data,
            collection_name=collection_name,
            search_field=search_field,
            search_params=search_params,
            limit=limit,
            object_type=object_type,
            output_fields=output_fields,
            expr=expr,
            partitions=partitions,
            timeout=timeout,
            round_decimal=round_decimal,
        )

        vector_query_spec.additional_properties = d
        return vector_query_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import *

import attr

from ..models.query_spec_object_type import QuerySpecObjectType
from ..types import UNSET, Unset

T = TypeVar("T", bound="QuerySpec")


def unset_if_none(_dict: dict, key: Any) -> Union[Any, Unset]:
    if key not in _dict or _dict[key] is None:
        return UNSET
    return _dict[key]


@attr.s(auto_attribs=True)
class QuerySpec:
    """
    Attributes:
        expr (str):
        collection_name (str):
        object_type (Union[Unset, QuerySpecObjectType]):  Default: QuerySpecObjectType.QUERYSPEC.
        output_fields (Union[Unset, List[str]]):
        partitions (Union[Unset, List[str]]):
        timeout (Union[Unset, float]):
    """

    expr: str
    collection_name: str
    object_type: Union[Unset, QuerySpecObjectType] = QuerySpecObjectType.QUERYSPEC
    output_fields: Union[Unset, List[str]] = UNSET
    partitions: Union[Unset, List[str]] = UNSET
    timeout: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def __init__(
        self,
        expr: str,
        collection_name: str,
        object_type: Union[Unset, QuerySpecObjectType] = QuerySpecObjectType.QUERYSPEC,
        output_fields: Union[Unset, List[str]] = UNSET,
        partitions: Union[Unset, List[str]] = UNSET,
        timeout: Union[Unset, float] = UNSET,
    ):
        """ """

        self.expr = expr
        self.collection_name = collection_name
        self.object_type = object_type
        self.output_fields = output_fields
        self.partitions = partitions
        self.timeout = timeout

    def to_dict(self) -> Dict[str, Any]:
        expr = self.expr
        collection_name = self.collection_name
        object_type: Union[Unset, str] = UNSET
        if not isinstance(self.object_type, Unset):
            object_type = self.object_type.value

        output_fields: Union[Unset, List[str]] = UNSET
        if not isinstance(self.output_fields, Unset):
            output_fields = self.output_fields

        partitions: Union[Unset, List[str]] = UNSET
        if not isinstance(self.partitions, Unset):
            partitions = self.partitions

        timeout = self.timeout

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "expr": expr,
                "collection_name": collection_name,
            }
        )
        if object_type is not UNSET:
            field_dict["object_type"] = object_type
        if output_fields is not UNSET:
            field_dict["output_fields"] = output_fields
        if partitions is not UNSET:
            field_dict["partitions"] = partitions
        if timeout is not UNSET:
            field_dict["timeout"] = timeout

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        expr = d.pop("expr")

        collection_name = d.pop("collection_name")

        _object_type = unset_if_none(d, "object_type")
        object_type: Union[Unset, QuerySpecObjectType]
        if isinstance(_object_type, Unset):
            object_type = UNSET
        else:
            object_type = QuerySpecObjectType(_object_type)

        output_fields = cast(List[str], unset_if_none(d, "output_fields"))

        partitions = cast(List[str], unset_if_none(d, "partitions"))

        timeout = unset_if_none(d, "timeout")

        query_spec = cls(
            expr=expr,
            collection_name=collection_name,
            object_type=object_type,
            output_fields=output_fields,
            partitions=partitions,
            timeout=timeout,
        )

        query_spec.additional_properties = d
        return query_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
